==> crypto-currency-icon-0.1.1.tgz: package/README.md <==
# crypto-currency-icon 

### [APB CSS](http://apbcss.com/) (Atomic Parts Base CSS) Architecture Base CryptoCurrency Icon CSS Style



## Table of contents

* [Quick start](#quick-start)
* [Documentation](#documentation)
* [Start Develop](#start-develop)
* [Creators](#creators)
* [Copyright and license](#copyright-and-license)

## Quick start

included html
```$xslt
<link rel="stylesheet" href="css/crypto-currency-icon.css">
```

**Install with [npm](https://www.npmjs.com):**
```
$ npm install crypto-currency-icon
```


**HTML**

example:

Bitcoin

![Bitcoin](https://webcyou.github.io/crypto-currency-icon/images/bitcoin_30.png)


```$xslt
<p class="icon cryptoCoin btc"></p>
```

Ripple

![Ripple](https://webcyou.github.io/crypto-currency-icon/images/ripple_30.png)

```$xslt
<p class="icon cryptoCoin xrp"></p>
```

add Size Variation.

![Ripple](https://webcyou.github.io/crypto-currency-icon/images/ripple_20.png)

```$xslt
<p class="icon cryptoCoin xrp small"></p>
```


**Icon Size CSS Class**

| size (px)     | css className |  images  |
|:-------------:|:-------------:|:--------:|
| 14px × 14px   | mini          | |
| 20px × 20px   | small         | |
| 30px × 30px   | medium        | |
| 50px × 50px   | large         | |
| 100px × 100px | big           | |



**Clone the repo:**

```$xslt
$ git clone git@github.com:webcyou/crypto-currency-icon.git
```


## Documentation

CryptoCurrency Icon CSS Style documentation, included in this repo in the root directory, is built with Hugo.


[CryptoCurrency Icon CSS](https://webcyou.github.io/crypto-currency-icon/)


## Start Develop

```$xslt
npm install
```

If necessary, install Hugo and other Go.

```$xslt
brew install hugo
```


```$xslt
npm run start
```

Open `http://localhost:1313` in your browser.


## Creators

**Daisuke Takayama**
* [@webcyou](https://twitter.com/webcyou)
* [@panicdragon](https://twitter.com/panicdragon)
* <https://github.com/webcyou>
* <https://github.com/panicdragon>
* <http://www.webcyou.com/>


## Copyright and license

MIT

==> crypto-currency-icon-0.1.2.tgz: package/README.md <==
# crypto-currency-icon 

### [APB CSS](http://apbcss.com/) (Atomic Parts Base CSS) Architecture Base CryptoCurrency Icon CSS Style



## Table of contents

* [Quick start](#quick-start)
* [Documentation](#documentation)
* [Start Develop](#start-develop)
* [Creators](#creators)
* [Copyright and license](#copyright-and-license)

## Quick start

included html
```$xslt
<link rel="stylesheet" href="css/crypto-currency-icon.css">
```

**Install with [npm](https://www.npmjs.com):**
```
$ npm install crypto-currency-icon
```


**HTML**

example:

Bitcoin

![Bitcoin](https://webcyou.github.io/crypto-currency-icon/images/bitcoin_30.png)


```$xslt
<p class="icon cryptoCoin btc"></p>
```

Ripple

![Ripple](https://webcyou.github.io/crypto-currency-icon/images/ripple_30.png)

```$xslt
<p class="icon cryptoCoin xrp"></p>
```

add Size Variation.

![Ripple](https://webcyou.github.io/crypto-currency-icon/images/ripple_20.png)

```$xslt
<p class="icon cryptoCoin xrp small"></p>
```


**Icon Size CSS Class**

| size (px)     | css className |  images  |
|:-------------:|:-------------:|:--------:|
| 14px × 14px   | mini          | ![Bitcoin](https://webcyou.github.io/crypto-currency-icon/images/bitcoin_14.png) |
| 20px × 20px   | small         | ![Bitcoin](https://webcyou.github.io/crypto-currency-icon/images/bitcoin_20.png) |
| 30px × 30px   | medium        | ![Bitcoin](https://webcyou.github.io/crypto-currency-icon/images/bitcoin_30.png) |
| 50px × 50px   | large         | ![Bitcoin](https://webcyou.github.io/crypto-currency-icon/images/bitcoin_50.png) |
| 100px × 100px | big           | ![Bitcoin](https://webcyou.github.io/crypto-currency-icon/images/bitcoin_100.png) |

Retina Display Image size.

**Clone the repo:**

```$xslt
$ git clone git@github.com:webcyou/crypto-currency-icon.git
```


## Documentation

CryptoCurrency Icon CSS Style documentation, included in this repo in the root directory, is built with Hugo.


[CryptoCurrency Icon CSS](https://webcyou.github.io/crypto-currency-icon/)


## Start Develop

```$xslt
npm install
```

If necessary, install Hugo and other Go.

```$xslt
brew install hugo
```


```$xslt
npm run start
```

Open `http://localhost:1313` in your browser.


## Creators

**Daisuke Takayama**
* [@webcyou](https://twitter.com/webcyou)
* [@panicdragon](https://twitter.com/panicdragon)
* <https://github.com/webcyou>
* <https://github.com/panicdragon>
* <http://www.webcyou.com/>


## Copyright and license

MIT
